@@ -5,28 +5,30 @@ OC.L10N.register(
     "Rename" : "Renomar",
     "Move" : "Mover",
     "Delete" : "Desaniciar",
-    "Save" : "Guardar",
+    "New" : "Nuevu",
     "New folder" : "Carpeta nueva",
     "Grid view" : "Vista de rexella",
     "List view" : "Vista de llista",
-    "Create" : "Crear",
+    "Select all" : "Esbillar too",
     "Cancel" : "Encaboxar",
+    "Recent" : "Reciente",
     "Import" : "Importar",
     "Export" : "Esportar",
     "Recently added" : "Amestao apocayá",
     "Alphabetically" : "Alfabéticamente",
     "Clear data" : "Llimpiar datos",
-    "URL" : "Url",
+    "Title" : "Títulu",
+    "Link" : "Link",
     "Tags" : "Etiquetes",
+    "Attachments" : "Axuntos",
     "Notes" : "Notes",
-    "Sharing" : "Compartiendo",
     "Owner" : "Owner",
+    "Sharing" : "Compartiendo",
     "Share link" : "Share link",
     "Copy link" : "Copiar enllaz",
     "Allow editing" : "Permitir edición",
     "Select" : "Esbillar",
-    "Title" : "Títulu",
-    "Link" : "Link",
-    "Folder" : "Carpeta"
+    "Folder" : "Carpeta",
+    "Save" : "Guardar"
 },
 "nplurals=2; plural=(n != 1);");
