@@ -8,41 +8,42 @@ OC.L10N.register(
     "Rename" : "Преименувай",
     "Move" : "Преместване",
     "Delete" : "Изтрий",
-    "Save" : "Запиши",
+    "New" : "Нов",
     "New folder" : "Нова папка",
     "Grid view" : "Решетъчен изглед",
     "List view" : "Списъчен изглед",
-    "Create" : "Създай",
+    "Select all" : "Избери всички",
     "Cancel" : "Отказ",
-    "Public" : "Публично",
+    "All bookmarks" : "Всички отметки",
+    "Recent" : "Последни",
     "Untagged" : "Без отметки",
+    "Add a bookmark" : "Добави отметка",
     "Import" : "Внасяне",
     "Export" : "Изнасяне",
     "Recently added" : "Последно добавени",
     "Alphabetically" : "По азбучен ред",
     "Most visited" : "Най-посещавани",
     "Last modified" : "Променена",
-    "RSS Feed" : "RSS емисия",
+    "Bookmarklet" : "Скриптова отметка",
     "Clear data" : "Изчисти данните",
     "Delete all bookmarks" : "Изтрий всички отметки",
-    "Bookmarklet" : "Скриптова отметка",
     "Do you really want to delete all your bookmarks?" : "Наистина ли желаете всички отметки да бъдат изтрити?",
-    "URL" : "URL",
+    "Title" : "Име",
+    "Link" : "Връзка",
     "Tags" : "Етикети",
+    "Attachments" : "Прикачени файлове",
     "Notes" : "Бележки",
-    "Sharing" : "Споделяне",
     "{time} ago" : "преди {time}",
     "Owner" : "Създател",
+    "Sharing" : "Споделяне",
     "Share link" : "Връзка за споделяне",
     "Copy link" : "Копирай връзката",
     "Allow editing" : "Разреши редактиране",
     "Link copied" : "Връзката е копирана",
     "Select" : "Маркирай",
     "Privacy" : "Защита на лични данни",
-    "Add a bookmark" : "Добави отметка",
     "This URL is already bookmarked! Overwrite?" : "Този адрес е вече добавен към отметките! Искате ли да презапишете?",
-    "Title" : "Име",
-    "Link" : "Връзка",
-    "Folder" : "Папка"
+    "Folder" : "Папка",
+    "Save" : "Запиши"
 },
 "nplurals=2; plural=(n != 1);");
