@@ -9,46 +9,45 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Move",
     "Delete" : "Delete",
-    "Save" : "Save",
+    "New" : "New",
     "New folder" : "New folder",
     "Grid view" : "Grid view",
     "List view" : "List view",
-    "Create" : "Create",
-    "Cancel" : "Cancel",
-    "Public" : "Public",
+    "Select all" : "Select all",
     "Root folder" : "Root folder",
+    "Cancel" : "Cancel",
+    "All bookmarks" : "All bookmarks",
+    "Recent" : "Recent",
+    "Add a bookmark" : "Add a bookmark",
     "Import" : "Import",
     "Export" : "Export",
     "Recently added" : "Recently added",
     "Alphabetically" : "Alphabetically",
     "Most visited" : "Most visited",
     "Last modified" : "Last modified",
-    "RSS Feed" : "RSS Feed",
-    "Clear data" : "Clear data",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "Permanently remove all bookmarks from your account. There is no going back!",
-    "Delete all bookmarks" : "Delete all bookmarks",
     "Bookmarklet" : "Bookmarklet",
+    "Clear data" : "Clear data",
+    "Delete all bookmarks" : "Delete all bookmarks",
     "Do you really want to delete all your bookmarks?" : "Do you really want to delete all your bookmarks?",
-    "URL" : "Url",
+    "Title" : "Title",
+    "Link" : "Link",
     "Tags" : "Tags",
+    "Attachments" : "Attachments",
     "Notes" : "Notes",
-    "Sharing" : "Sharing",
     "Owner" : "Owner",
+    "Sharing" : "Sharing",
     "Share link" : "Share link",
     "Copy link" : "Copy link",
     "Allow editing" : "Allow editing",
     "Link copied" : "Link copied",
     "Select" : "Select",
     "Previews" : "Previews",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those.",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API key",
     "Privacy" : "Privacy",
-    "Add a bookmark" : "Add a bookmark",
     "This URL is already bookmarked! Overwrite?" : "This URL is already bookmarked! Overwrite?",
-    "Title" : "Title",
-    "Link" : "Link",
     "Folder" : "Folder",
+    "Save" : "Save",
     "Bookmarks feed" : "Bookmarks feed"
 },
 "nplurals=2; plural=(n != 1);");
