@@ -10,30 +10,27 @@ OC.L10N.register(
     "Rename" : "Alinomi",
     "Move" : "Movi",
     "Delete" : "Forigi",
-    "Enter bookmark title" : "Entajpu titolon de la legosigno",
-    "Save" : "Konservi",
-    "No bookmarks here" : "Neniu legosigno ĉi tie",
-    "Try changing your query or add some using the button on the left." : "Provu ŝanĝi vian peton aŭ aldoni kelkajn per uzo de la butono maldekstre.",
     "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
+    "New" : "Nova",
     "New folder" : "Nova dosierujo",
     "Grid view" : "Krada vido",
     "List view" : "Lista vido",
     "Move selection" : "Movi elekton",
     "Delete selection" : "Forigi elekton",
+    "Select all" : "Elekti ĉion",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n legosignon elektitan","%n legosignojn elektitajn"],
     "Enter a link" : "Entajpu ligilon",
-    "Create" : "Krei",
-    "Cancel" : "Nuligi",
     "Enter folder title" : "Entajpu titolon de la dosierujo",
-    "Public" : "Publika",
     "Root folder" : "Radika dosierujo",
+    "Cancel" : "Nuligi",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
     "_Moving %n folder_::_Moving %n folders_" : ["Movo de %n dosierujo","Movo de %n dosierujoj"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movo de %n legosigno","Movo de %n legosignoj"],
-    "New Bookmark" : "Nova legosigno",
-    "All Bookmarks" : "Ĉiuj legosignoj",
-    "Recent Bookmarks" : "Lastaj legosignoj",
+    "All bookmarks" : "Ĉiuj legosignoj",
+    "Recent" : "Lastaj ŝanĝoj",
     "Untagged" : "Sen etikedo",
+    "No bookmarks here" : "Neniu legosigno ĉi tie",
+    "Add a bookmark" : "Aldoni legosignon",
     "Import" : "Importi",
     "Export" : "Eksporti",
     "Sorting" : "Ordigo",
@@ -41,25 +38,23 @@ OC.L10N.register(
     "Alphabetically" : "Alfabete",
     "Most visited" : "Plej vizititaj",
     "Last modified" : "laŭ lasta modifo",
-    "RSS Feed" : "RSS-fluo",
-    "This is an RSS feed of the current result set with access restricted to you." : "Tio estas (RSS) abonfluo de la nuna rezultaro kun aliro nur por vi.",
-    "Clear data" : "Forviŝi datumojn",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "Porĉiame forigi ĉiujn legosignojn el via konto. Ne eblos malfari tion!",
-    "Delete all bookmarks" : "Forigi ĉiujn legosignojn",
+    "Client apps" : "Klientaj aplikaĵoj",
+    "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
     "Bookmarklet" : "Legosignilo",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Ŝovu tion al via retumila legosignaro  kaj alklaku ĝin por rapide aldoni al viaj legosignoj retpaĝon",
     "Add to {instanceName}" : "Aldoni al {instanceName}",
-    "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
-    "Client apps" : "Klientaj aplikaĵoj",
+    "Clear data" : "Forviŝi datumojn",
+    "Delete all bookmarks" : "Forigi ĉiujn legosignojn",
     "Do you really want to delete all your bookmarks?" : "Ĉu vi ja volas forigi ĉiujn viaj legosignoj?",
-    "URL" : "Retadreso",
+    "Title" : "Titolo",
+    "Link" : "Ligilo",
     "Creation date" : "Krea dato",
     "Tags" : "Etikedoj",
-    "Select tags are create new ones" : "Elekti etikedojn aŭ krei novajn",
+    "Attachments" : "Dosieraj aldonaĵoj",
     "Notes" : "Notoj",
-    "Sharing" : "Kunhavigo",
     "{time} ago" : "antaŭ {time}",
     "Owner" : "Posedanto",
+    "Sharing" : "Kunhavigo",
     "Select a user or group" : "Elektu uzanton aŭ grupon",
     "Share link" : "Kunhavigi ligilon",
     "Copy link" : "Kopii ligilon",
@@ -67,7 +62,6 @@ OC.L10N.register(
     "Link copied" : "Ligilo kopiita",
     "Select" : "Elekti",
     "Previews" : "Antaŭrigardoj",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Por vidigi realajn ekrankopiojn de viaj legosignoj, Legosignaro povas uzi servon de ekstera liveranto por krei ilin.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Vi povas aŭ krei senpagan konton ĉe screeenly.com aŭ instali vian propran servilon.",
     "Screeenly API URL" : "API-adreso de Screeenly",
@@ -76,15 +70,13 @@ OC.L10N.register(
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "„Legosignaro“ provos aliri retpaĝojn, kiujn vi aldonas por aldoni aŭtomate informojn pri ili.",
     "Enable accessing and collecting information from the web pages you add" : "Ebligi aliron al kaj kolekton de informoj el la retpaĝoj, kiujn vi aldonas",
     "Performance" : "Rendimento",
-    "In an installation with  a lot of users it may be useful to restrict the number of bookmarks per account." : "Ĉe servo kun multe da uzantoj, eble utilas limigi la nombrojn de legosignoj por ĉiu konto.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimuma nombro de legosignoj en unu konto. (0 por ne limigi; defaŭlte ne estas limigo)",
     "Failed to load settings" : "Ŝargo de agordoj malsukcesis",
     "Failed to save settings" : "Konservo de agordoj malsukcesis",
-    "Add a bookmark" : "Aldoni legosignon",
     "This URL is already bookmarked! Overwrite?" : "Tiu adreso jam ekzistas en viaj legosignoj! Anstataŭigi ĝin?",
-    "Title" : "Titolo",
-    "Link" : "Ligilo",
+    "Enter bookmark title" : "Entajpu titolon de la legosigno",
     "Folder" : "Dosierujo",
+    "Save" : "Konservi",
     "Failed to find existing bookmark" : "Trovo de jam ekzistanta legosigno malsukcesis",
     "Failed to create bookmark" : "Kreo de legosigno malsukcesis",
     "Failed to save bookmark" : "Konservo de legosigno malsukcesis",
@@ -94,8 +86,6 @@ OC.L10N.register(
     "Failed to load folders" : "Ŝargo de la dosierujoj malsukcesis",
     "Failed to delete folder" : "Forigo de la dosierujo malsukcesis",
     "Failed to create folder" : "Kreo de dosierujo malsukcesis",
-    "Failed to move parts of selection" : "Movo de partoj de la elekto malsukcesis",
-    "Failed to delete parts of selection" : "Malsukceso forigi partojn de elekto",
     "Failed to fetch bookmarks." : "Ricevo de legosignoj malsukcesis.",
     "Failed to change setting" : "Ŝanĝo de agordo malsukcesis",
     "Bookmarks feed" : "Fluo de legosignoj"
