@@ -5,32 +5,32 @@ OC.L10N.register(
     "Rename" : "Nimeta ümber",
     "Move" : "Liiguta",
     "Delete" : "Kustuta",
-    "Save" : "Salvesta",
+    "New" : "Uus",
     "New folder" : "Uus kaust",
     "Grid view" : "Ruudustikvaade",
     "List view" : "Nimekirjavaade",
-    "Create" : "Loo",
+    "Select all" : "Vali kõik",
     "Cancel" : "Loobu",
-    "Public" : "Avalik",
+    "Recent" : "Hiljutised",
     "Import" : "Impordi",
     "Export" : "Ekspordi",
     "Recently added" : "Viimati lisatud",
     "Alphabetically" : "Tähestikujärjekorras",
     "Last modified" : "Viimati muudetud",
     "Clear data" : "Tühjenda andmed",
-    "URL" : "URL",
+    "Title" : "Pealkiri",
+    "Link" : "Link",
     "Tags" : "Sildid",
     "Notes" : "Märkmed",
-    "Sharing" : "Jagamine",
     "Owner" : "Omanik",
+    "Sharing" : "Jagamine",
     "Share link" : "Jaga link",
     "Copy link" : "Kopeeri link",
     "Allow editing" : "Luba muutmine",
     "Link copied" : "Link kopeeritud",
     "Select" : "Vali",
     "Privacy" : "Privaatsus",
-    "Title" : "Pealkiri",
-    "Link" : "Link",
-    "Folder" : "Kaust"
+    "Folder" : "Kaust",
+    "Save" : "Salvesta"
 },
 "nplurals=2; plural=(n != 1);");
