@@ -10,30 +10,26 @@ OC.L10N.register(
     "Rename" : "تغییرنام",
     "Move" : "انتقال",
     "Delete" : "حذف",
-    "Enter bookmark title" : "عنوان نشانک را وارد کنید",
-    "Save" : "ذخیره",
-    "No bookmarks here" : "در اینجا هیچ نشانک وجود ندارد",
-    "Try changing your query or add some using the button on the left." : "سعی کنید درخواست خود را تغییر دهید یا با استفاده از دکمه سمت چپ مقداری اضافه کنید.",
     "Select one or more tags" : "یک یا چند تگ را انتخاب کنید",
+    "New" : "جدید",
     "New folder" : "پوشه جدید",
     "Grid view" : "نمایش گرید",
     "List view" : "نمایش لیست",
     "Move selection" : "انتخاب را جابجا کنید",
     "Delete selection" : "انتخاب را حذف کنید",
+    "Select all" : "انتخاب همه",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["انتخاب شده %n نشانک","انتخاب شده %n نشانک های"],
     "Enter a link" : "پیوند را وارد کنید",
-    "Create" : "ایجاد کردن",
-    "Cancel" : "لغو",
     "Enter folder title" : "عنوان پوشه را وارد کنید",
-    "Public" : "عمومی",
     "Root folder" : "پوشهٔ ریشه",
+    "Cancel" : "لغو",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["در حال انتقال %nپوشه ها و برخی نشانک ها","در حال انتقال %n پوشه ها و برخی نشانک ها"],
     "_Moving %n folder_::_Moving %n folders_" : ["در حال انتقال %n پوشه","در حال انتقال %n پوشه ها"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["در حال انتقال %n نشانک","در حال انتقال %n نشانک ها"],
-    "New Bookmark" : "نشانک جدید",
-    "All Bookmarks" : "همه نشنک ها",
-    "Recent Bookmarks" : "نشانک های اخیر",
+    "Recent" : "اخیر",
     "Untagged" : "غیرقابل تشخیص",
+    "No bookmarks here" : "در اینجا هیچ نشانک وجود ندارد",
+    "Add a bookmark" : "یک نشانک اضافه کنید",
     "Import" : "وارد کردن",
     "Export" : "گرفتن خروجی",
     "Sorting" : "مرتب سازی",
@@ -41,25 +37,23 @@ OC.L10N.register(
     "Alphabetically" : "الفبایی",
     "Most visited" : "بیشترین بازدید",
     "Last modified" : "آخرین اصلاح شده",
-    "RSS Feed" : "RSS Feed",
-    "This is an RSS feed of the current result set with access restricted to you." : "این یک RSS feed از نتایج فعلی تنظیم شده با دسترسی محدود به شما است .",
-    "Clear data" : "داده روشن",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "تمام نشانک ها را کاملا از حساب خود حذف کنید. برگشتی وجود ندارد!",
-    "Delete all bookmarks" : "حذف همه نشانک ها",
+    "Client apps" : "برنامه های مشتری",
+    "Also check out the collection of client apps that integrate with this app: " : "همچنین مجموعه برنامه های مشتری که با این برنامه ادغام شده اند را بررسی کنید:",
     "Bookmarklet" : "نشانک",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "این مورد را به نشانک های مرورگر خود بکشید و روی آن کلیک کنید تا سریع یک صفحه وب نشانک گذاری شود",
     "Add to {instanceName}" : "افزودن به {instanceName}",
-    "Also check out the collection of client apps that integrate with this app: " : "همچنین مجموعه برنامه های مشتری که با این برنامه ادغام شده اند را بررسی کنید:",
-    "Client apps" : "برنامه های مشتری",
+    "Clear data" : "داده روشن",
+    "Delete all bookmarks" : "حذف همه نشانک ها",
     "Do you really want to delete all your bookmarks?" : "آیا واقعاً می خواهید تمام نشانک های خود را حذف کنید؟",
-    "URL" : "URL",
+    "Title" : "عنوان",
+    "Link" : "Link",
     "Creation date" : "تاریخ ایجاد",
     "Tags" : "برچسب‌ها",
-    "Select tags are create new ones" : "برچسب های انتخاب شده ، موارد جدیدی ایجاد می کنند",
+    "Attachments" : "پیوست‌ها",
     "Notes" : "یادداشت ها",
-    "Sharing" : "اشتراک گذاری",
     "{time} ago" : "{time} قبل",
     "Owner" : "صاحب",
+    "Sharing" : "اشتراک گذاری",
     "Select a user or group" : "کاربر یا گروهی را انتخاب کنید",
     "Share link" : "لینک را به اشتراک بگذارید",
     "Copy link" : "کپی کردن لینک",
@@ -67,7 +61,6 @@ OC.L10N.register(
     "Link copied" : "پیوند کپی شد",
     "Select" : "انتخاب",
     "Previews" : "پیش نمایش ها",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "به منظور نمایش تصاویر واقعی از وب سایتهای نشانک شده خود ، نشانک ها می توانند از یک سرویس شخص ثالث برای تولید آن استفاده کنند.",
     "Screeenly" : "صفحه نمایش",
     "You can either sign up for free at screeenly.com or setup your own server." : "می توانید به صورت رایگان در screeenly.com ثبت نام کنید یا سرور خود را راه اندازی کنید.",
     "Screeenly API URL" : "Screeenly API URL",
@@ -76,16 +69,14 @@ OC.L10N.register(
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "نشانک ها سعی می کنند به صفحات وب اضافه شده دسترسی پیدا کنند تا به طور خودکار اطلاعات مربوط به آنها اضافه شود.",
     "Enable accessing and collecting information from the web pages you add" : "دسترسی و جمع آوری اطلاعات از صفحات وب اضافه شده را فعال کنید",
     "Performance" : "کارایی",
-    "In an installation with  a lot of users it may be useful to restrict the number of bookmarks per account." : "در نصب با تعداد زیادی از کاربران ممکن است محدود کردن تعداد نشانک ها در هر حساب مفید باشد.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "حداکثر تعداد نشانک های مجاز در هر حساب. (0 بدون محدودیت است ؛ پیش فرض هیچ محدودیتی نیست)",
     "Failed to load settings" : "تنظیمات بارگیری نشد",
     "Failed to save settings" : "تنظیمات ذخیره نشدند",
-    "Add a bookmark" : "یک نشانک اضافه کنید",
     "This URL is already bookmarked! Overwrite?" : "این URL از قبل نشانک گذاری شده است! دوباره نشانک گذاری شود؟",
-    "Title" : "عنوان",
-    "Link" : "Link",
+    "Enter bookmark title" : "عنوان نشانک را وارد کنید",
     "Enter bookmark URL" : "URL نشانک را وارد کنید",
     "Folder" : "پوشه",
+    "Save" : "ذخیره",
     "Failed to find existing bookmark" : "یافتن نشانک موجود انجام نشد",
     "Failed to create bookmark" : "ایجاد نشانک انجام نشد",
     "Failed to save bookmark" : "ذخیره نشانک انجام نشد",
@@ -95,8 +86,6 @@ OC.L10N.register(
     "Failed to load folders" : "بارگیری پوشه ها انجام نشد",
     "Failed to delete folder" : "پوشه حذف نشد",
     "Failed to create folder" : "پوشه ایجاد نشد",
-    "Failed to move parts of selection" : "جابجایی بخش های انتخاب انجام نشد",
-    "Failed to delete parts of selection" : "حذف قسمتهای انتخاب انجام نشد",
     "Failed to fetch bookmarks." : "واکشی نشانک ها انجام نشد.",
     "Failed to change setting" : "تنظیم تغییر نکرد",
     "Bookmarks feed" : "بازخورد نشانک ها"
