@@ -5,25 +5,26 @@ OC.L10N.register(
     "Rename" : "Renominar",
     "Move" : "Mover",
     "Delete" : "Deler",
-    "Save" : "Salveguardar",
+    "New" : "Nove",
     "New folder" : "Nove dossier",
-    "Create" : "Crear",
+    "Select all" : "Selectionar toto",
     "Cancel" : "Cancellar",
-    "Public" : "Public",
+    "Recent" : "Recente",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Alphabetically" : "Alphabeticamente",
-    "URL" : "URL",
+    "Title" : "Titulo",
+    "Link" : "Ligamine",
     "Tags" : "Etiquettas",
+    "Attachments" : "Attachamentos",
     "Notes" : "Notas",
-    "Sharing" : "Compartente",
     "Owner" : "Owner",
+    "Sharing" : "Compartente",
     "Share link" : "Compartir ligamine",
     "Copy link" : "Copiar ligamine",
     "Allow editing" : "Permitter modificar",
     "Select" : "Selectionar",
-    "Title" : "Titulo",
-    "Link" : "Ligamine",
-    "Folder" : "Dossier"
+    "Folder" : "Dossier",
+    "Save" : "Salveguardar"
 },
 "nplurals=2; plural=(n != 1);");
