@@ -11,11 +11,8 @@ OC.L10N.register(
     "Rename" : "Endurnefna",
     "Move" : "Færa",
     "Delete" : "Eyða",
-    "Enter bookmark title" : "Settu inn titil á bókamerki",
-    "Save" : "Vista",
-    "No bookmarks here" : "Engin bókamerki hér",
-    "Try changing your query or add some using the button on the left." : "Reyndu að breyta fyrirspurninni eða bæta við skilyrðum með því að nota hnappinn til vinstri..",
     "Select one or more tags" : "Veldu eitt eða fleiri merki",
+    "New" : "Nýtt",
     "New bookmark" : "Nýtt bókamerki",
     "New folder" : "Ný mappa",
     "Grid view" : "Reitasýn",
@@ -23,28 +20,26 @@ OC.L10N.register(
     "Move selection" : "Færa valið",
     "Delete selection" : "Eyða vali",
     "Open all selected" : "Opna allt valið",
-    "Select all visible" : "Velja allt sýnilegt",
+    "Select all" : "Select all",
     "Cancel selection" : "Hætta við val",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valdi %n bókamerki","Valdi %n bókamerki"],
     "_Selected %n folder_::_Selected %n folders_" : ["Valin %n mappa","Valdar %n möppur"],
     "Enter a link" : "Settu inn slóð",
-    "Create" : "Búa til",
-    "Cancel" : "Hætta við",
-    "Enter folder title" : "Settu inn heiti möppu",
     "Select folder" : "Veldu möppu",
+    "Enter folder title" : "Settu inn heiti möppu",
     "Shared by {user}" : "Deilt af {user}",
-    "Shared privately" : "Deilt sem einkamáli",
-    "Public" : "Opinbert",
     "Root folder" : "Rótarmappa",
+    "Cancel" : "Hætta við",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Færi %n möppu og einhver bókamerki","Færi %n möppur og einhver bókamerki"],
     "_Moving %n folder_::_Moving %n folders_" : ["Færi %n möppu","Færi %n möppur"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Færi %n bókamerki","Færi %n bókamerki"],
-    "New Bookmark" : "Nýtt bókamerki",
-    "All Bookmarks" : "Öll bókamerki",
-    "Recent Bookmarks" : "Nýleg bókamerki",
+    "All bookmarks" : "Öll bókamerki",
+    "Recent" : "Nýlegt",
     "Untagged" : "Ómerkt",
     "{used} bookmarks of {available} available" : "{used} bókamerki af {available} tiltækum",
+    "No bookmarks here" : "Engin bókamerki hér",
+    "Add a bookmark" : "Bæta við bókamerki",
     "Import" : "Flytja inn",
     "Export" : "Flytja út",
     "Sorting" : "Röðun",
@@ -52,25 +47,23 @@ OC.L10N.register(
     "Alphabetically" : "Í stafrófsröð",
     "Most visited" : "Mest heimsótt",
     "Last modified" : "Síðast breytt",
-    "RSS Feed" : "RSS streymi",
-    "This is an RSS feed of the current result set with access restricted to you." : "Þetta er RSS-streymi með fyrirliggjandi niðurstöður þar sem aðgangur er takmarkaður við þig.",
-    "Clear data" : "Hreinsa gögn",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "Eyddu varanlega öllum bókamerkjum úr aðgangnum þínum. Ekki er hægt að afturkalla þetta!",
-    "Delete all bookmarks" : "Eyða öllum bókamerkjum",
+    "Client apps" : "Biðlaraforrit",
+    "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
     "Bookmarklet" : "Bókamerklingur",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Dragðu þetta yfir í bókamerkin í vafranum þínu og smelltu, ef þú vilt bæta við bókamerki fyrir þessa vefsíðu á fljótlegan hátt",
     "Add to {instanceName}" : "Bæta við {instanceName}",
-    "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
-    "Client apps" : "Biðlaraforrit",
+    "Clear data" : "Hreinsa gögn",
+    "Delete all bookmarks" : "Eyða öllum bókamerkjum",
     "Do you really want to delete all your bookmarks?" : "Viltu í alvörunni eyða öllum bókmerkjunum þínum?",
-    "URL" : "Slóð (URL)",
+    "Title" : "Titill",
+    "Link" : "Tengill",
     "Creation date" : "Upprunadagsetning",
     "Tags" : "Merki",
-    "Select tags are create new ones" : "Veldu merki eða útbúðu ný",
+    "Attachments" : "Viðhengi",
     "Notes" : "Minnispunktar",
-    "Sharing" : "Deiling",
     "{time} ago" : "fyrir {time} síðan",
     "Owner" : "Eigandi",
+    "Sharing" : "Deiling",
     "Select a user or group" : "Veldu notanda eða hóp",
     "Share link" : "Deila tengli",
     "Copy link" : "Afrita tengil",
@@ -84,7 +77,6 @@ OC.L10N.register(
     "RSS feed copied" : "RSS-fréttastreymi afritað",
     "Select" : "Velja",
     "Previews" : "Forskoðun",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Til þess að birta raunverulegar skjámyndir af þeim vefsíðum sem þú bókamerkir, getur bókamerkjaforritið notað þjónustu utanaðkomandi aðila til að útbúa skjámyndirnar.",
     "Screeenly" : "Screeenly",
     "You can either sign up for free at screeenly.com or setup your own server." : "Þú getur annað hvort skráð þig ókeypis á  screeenly.com eða sett upp þinn eigin þjón.",
     "Screeenly API URL" : "Slóð á API-forritsviðmót Screenly",
@@ -93,17 +85,15 @@ OC.L10N.register(
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bókamerkjaforritið mun reyna að fá aðgang að þeim síðum sem þú bætir við til að sækja sjálfvirkt upplýsingar um þær.",
     "Enable accessing and collecting information from the web pages you add" : "Virkja aðgang og söfnun upplýsinga af vefsíðunum sem þú bætir við",
     "Performance" : "Afköst",
-    "In an installation with  a lot of users it may be useful to restrict the number of bookmarks per account." : "Á uppsetningum með mikinn fjölda notenda getur verið skynsamlegt að takmarka fjölda bókamerkja á hvern notandaaðgang.",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Leyfður hámarksföldi bókamerkja á hvern notandaaðgang. (0 fyrir engin takmörk; það er sjálfgefið)",
     "Failed to load settings" : "Mistókst að hlaða inn stillingum",
     "Failed to save settings" : "Mistókst að vista stillingar",
-    "Add a bookmark" : "Bæta við bókamerki",
     "This URL is already bookmarked! Overwrite?" : "Þessi slóð er þegar bókamerkt! Skrifa yfir?",
-    "Title" : "Titill",
-    "Link" : "Tengill",
+    "Enter bookmark title" : "Settu inn titil á bókamerki",
     "Enter bookmark URL" : "Settu inn slóð á bókamerki",
     "Folder" : "Mappa",
     "Root Folder" : "Rótarmappa",
+    "Save" : "Vista",
     "Failed to find existing bookmark" : "Mistókst að finna fyrirliggjandi bókamerki",
     "Failed to create bookmark" : "Mistókst að búa til bókamerki",
     "Failed to save bookmark" : "Mistókst að vista bókamerki",
@@ -113,8 +103,6 @@ OC.L10N.register(
     "Failed to load folders" : "Mistókst að hlaða inn möppum",
     "Failed to delete folder" : "Mistókst að eyða möppu",
     "Failed to create folder" : "Mistókst að búa til möppu",
-    "Failed to move parts of selection" : "Mistókst að færa hluta af völdu",
-    "Failed to delete parts of selection" : "Mistókst að eyða hluta af völdu",
     "Failed to fetch bookmarks." : "Ekki tókst að sækja bókamerki.",
     "Failed to change setting" : "Mistókst að breyta stillingu",
     "Failed to load setting {key}" : "Mistókst að hlaða inn {key} stillingunni",
