@@ -8,34 +8,34 @@ OC.L10N.register(
     "Rename" : "სახელის შეცვლა",
     "Move" : "გადატანა",
     "Delete" : "წაშლა",
-    "Save" : "შენახვა",
+    "New" : "ახალი",
     "New folder" : "ახალი დირექტორია",
     "Grid view" : "ბადისებური ხედი",
     "List view" : "ჩამონათვლისებური ხედი",
-    "Create" : "შექმნა",
+    "Select all" : "ყველას არჩევა",
     "Cancel" : "უარყოფა",
-    "Public" : "ღია",
+    "Recent" : "ახალი",
+    "Add a bookmark" : "სანიშნის დამატება",
     "Import" : "იმპორტი",
     "Export" : "ექსპორტი",
     "Recently added" : "ახლად დამატებული",
     "Alphabetically" : "ანბანის მიხედვით",
     "Last modified" : "ბოლო ცვლილება",
-    "Clear data" : "მონაცემების გასუფთავება",
     "Bookmarklet" : "Bookmarklet-ი",
-    "URL" : "მისამართი",
+    "Clear data" : "მონაცემების გასუფთავება",
+    "Title" : "სათაური",
+    "Link" : "ბმული",
     "Tags" : "ტეგები",
     "Notes" : "ჩანაწერები",
-    "Sharing" : "გაზიარება",
     "Owner" : "მფლობელი",
+    "Sharing" : "გაზიარება",
     "Share link" : "ბმულის გაზიარება",
     "Copy link" : "ბმულის კოპირება",
     "Allow editing" : "შეცვლის ნების დართვა",
     "Select" : "არჩევა",
     "Privacy" : "კონფიდენციალურობა",
-    "Add a bookmark" : "სანიშნის დამატება",
     "This URL is already bookmarked! Overwrite?" : "ეს URL უკვე მონიშნულია! გადავწეროთ?",
-    "Title" : "სათაური",
-    "Link" : "ბმული",
-    "Folder" : "დირექტორია"
+    "Folder" : "დირექტორია",
+    "Save" : "შენახვა"
 },
 "nplurals=2; plural=(n!=1);");
