@@ -11,27 +11,23 @@ OC.L10N.register(
     "Rename" : "이름 바꾸기",
     "Move" : "이동",
     "Delete" : "삭제",
-    "Enter bookmark title" : "북마크 제목을 입력하시오.",
-    "Save" : "저장",
+    "New" : "새로 만들기",
     "New bookmark" : "새로운 북마크",
     "New folder" : "새 폴더",
     "Grid view" : "바둑판식 보기",
     "List view" : "목록 보기",
+    "Select all" : "Select all",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["선택된 %n 북마크들"],
     "_Selected %n folder_::_Selected %n folders_" : ["선택된 %n 폴더들"],
     "Enter a link" : "링크를 입력하시오.",
-    "Create" : "생성",
-    "Cancel" : "취소",
-    "Enter folder title" : "폴더명을 입력하시오.",
     "Select folder" : "폴더 선택",
+    "Enter folder title" : "폴더명을 입력하시오.",
     "Shared by {user}" : "{user}가 공유한",
-    "Shared privately" : "사적으로 공유됨",
-    "Public" : "공개",
     "Root folder" : "루트 폴더",
-    "New Bookmark" : "새로운 북마크",
-    "All Bookmarks" : "모든 북마크",
-    "Recent Bookmarks" : "최근 북마크",
+    "Cancel" : "취소",
+    "Recent" : "최근 항목",
     "Untagged" : "태그 지우기",
+    "Add a bookmark" : "북마크 추가",
     "Import" : "가져오기",
     "Export" : "내보내기",
     "Sorting" : "정렬",
@@ -39,19 +35,19 @@ OC.L10N.register(
     "Alphabetically" : "가나다순",
     "Most visited" : "가장 자주 방문함",
     "Last modified" : "수정한 날짜",
-    "RSS Feed" : "RSS 피드",
-    "Clear data" : "데이터 지우기",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "계정에 있는 모든 북마크를 삭제합니다. 실행 취소할 수 없습니다!",
-    "Delete all bookmarks" : "모든 북마크 삭제",
     "Bookmarklet" : "북마크릿",
     "Add to {instanceName}" : "{instanceName}에 더하기",
+    "Clear data" : "데이터 지우기",
+    "Delete all bookmarks" : "모든 북마크 삭제",
     "Do you really want to delete all your bookmarks?" : "모든 북마크를 삭제하시겠습니까?",
-    "URL" : "URL",
+    "Title" : "직위",
+    "Link" : "링크",
     "Tags" : "태그",
+    "Attachments" : "첨부파일",
     "Notes" : "Notes",
-    "Sharing" : "공유",
     "{time} ago" : "{time} 전에",
     "Owner" : "Owner",
+    "Sharing" : "공유",
     "Share link" : "링크 공유",
     "Copy link" : "링크 복사",
     "Delete link" : "링크 삭제",
@@ -59,19 +55,17 @@ OC.L10N.register(
     "Link copied" : "링크 복사됨",
     "Select" : "선택",
     "Previews" : "미리 보기",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "북마크된 웹사이트의 실제 화면을 표시할 때 북마크 앱에서 외부 서비스를 사용할 수도 있습니다.",
     "Screeenly API URL" : "Screeenly API URL",
     "Screeenly API key" : "Screeenly API 키",
     "Privacy" : "프라이버시",
     "Failed to load settings" : "환경설정 로딩 실패",
     "Failed to save settings" : "환경설정 저장 실패",
-    "Add a bookmark" : "북마크 추가",
     "This URL is already bookmarked! Overwrite?" : "이 URL이 북마크에 이미 추가되어 있습니다! 덮어쓰시겠습니까?",
-    "Title" : "직위",
-    "Link" : "링크",
+    "Enter bookmark title" : "북마크 제목을 입력하시오.",
     "Enter bookmark URL" : "북마크 URL을 입력하시오.",
     "Folder" : "폴더",
     "Root Folder" : "최상위 폴더",
+    "Save" : "저장",
     "Bookmarks feed" : "북마크 피드"
 },
 "nplurals=1; plural=0;");
