@@ -9,45 +9,43 @@ OC.L10N.register(
     "Rename" : "Pārsaukt",
     "Move" : "Pārvietot",
     "Delete" : "Dzēst",
-    "Save" : "Saglabāt",
+    "New" : "Jauns",
     "New folder" : "Jauna mape",
     "Grid view" : "Režģa izkārtojums",
     "List view" : "Saraksta izkārtojums",
-    "Create" : "Izveidot",
+    "Select all" : "Atzīmēt visu",
     "Cancel" : "Atcelt",
-    "Public" : "Publiska",
+    "Recent" : "Nesenās",
+    "Add a bookmark" : "Pievienot grāmatzīmi",
     "Import" : "Importēt",
     "Export" : "Eksportēt",
     "Recently added" : "Nesen pievienoja",
     "Alphabetically" : "Alfabētiskā secībā",
     "Most visited" : "Visapmeklētākie",
     "Last modified" : "Pēdējoreiz modificēts",
-    "RSS Feed" : "RSS plūsma",
-    "Clear data" : "Notīrīt datus",
-    "Permanently remove all bookmarks from your account. There is no going back!" : "Neatgriezeniski noņemt no sava konta visas grāmatzīmes. Nav atgriešanās!",
-    "Delete all bookmarks" : "Dzēst visas grāmatzīmes",
     "Bookmarklet" : "Grāmatzīme",
+    "Clear data" : "Notīrīt datus",
+    "Delete all bookmarks" : "Dzēst visas grāmatzīmes",
     "Do you really want to delete all your bookmarks?" : "Vai tiešām vēlaties dzēst visas savas grāmatzīmes?",
-    "URL" : "URL",
+    "Title" : "Amats",
+    "Link" : "Saite",
     "Tags" : "Birkas",
+    "Attachments" : "Pielikumi",
     "Notes" : "Piezīmes",
-    "Sharing" : "Koplietošana",
     "Owner" : "Īpašnieks",
+    "Sharing" : "Koplietošana",
     "Share link" : "Koplietot saiti",
     "Copy link" : "Kopēt saiti",
     "Allow editing" : "Atļaut rediģēšanu",
     "Link copied" : "Saite nokopēta",
     "Select" : "Atzīmēt",
     "Previews" : "Priekšskatījumi",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Lai parādītu jūsu grāmatzīmju vietņu reālos ekrānuzņēmumus, grāmatzīmes to ģenerēšanai var izmantot trešās puses pakalpojumu.",
     "Screeenly API URL" : "Screeenly API saite",
     "Screeenly API key" : "Screeenly API atslēga",
     "Privacy" : "Privātums",
-    "Add a bookmark" : "Pievienot grāmatzīmi",
     "This URL is already bookmarked! Overwrite?" : "Šī saite jau ir grāmatzīmēs! Vai pārrakstīt?",
-    "Title" : "Amats",
-    "Link" : "Saite",
     "Folder" : "Mape",
+    "Save" : "Saglabāt",
     "Bookmarks feed" : "Grāmatzīmju plūsma"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
