@@ -5,23 +5,24 @@ OC.L10N.register(
     "Rename" : "Преименувај",
     "Move" : "Премести",
     "Delete" : "Избриши",
-    "Save" : "Зачувај",
+    "New" : "Ново",
     "New folder" : "Нова папка",
     "Grid view" : "Мрежа",
     "List view" : "Листа",
-    "Create" : "Креирај",
+    "Select all" : "Избери се",
     "Cancel" : "Откажи",
-    "Public" : "Јавна",
+    "Recent" : "Неодамнешни",
     "Import" : "Увези",
     "Export" : "Извези",
     "Recently added" : "Скоро додадени",
     "Last modified" : "Скоро изменети",
     "Clear data" : "Исчисти податоци",
-    "URL" : "Адреса",
+    "Title" : "Наслов",
+    "Link" : "Линк",
     "Tags" : "Ознаки",
     "Notes" : "Белешки",
-    "Sharing" : "Споделување",
     "Owner" : "Сопственик",
+    "Sharing" : "Споделување",
     "Share link" : "Сподели линк",
     "Copy link" : "Копирај линк",
     "Allow editing" : "Овозможи уредување",
@@ -29,8 +30,7 @@ OC.L10N.register(
     "Select" : "Select",
     "Privacy" : "Приватност",
     "Failed to save settings" : "Неуспешно зачувување на параметрите",
-    "Title" : "Наслов",
-    "Link" : "Линк",
-    "Folder" : "Папка"
+    "Folder" : "Папка",
+    "Save" : "Зачувај"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
