@@ -5,27 +5,28 @@ OC.L10N.register(
     "Rename" : "Нэрлэнэ үү",
     "Move" : "Зөөх",
     "Delete" : "Устгах",
-    "Save" : "Хадгалах",
+    "New" : "Шинэ",
     "New folder" : "Шинэ хавтас",
-    "Create" : "Үүсгэх",
+    "Select all" : "бүгдийг сонгох",
     "Cancel" : "болиулах",
-    "Public" : "Нийтийн",
+    "Recent" : "Сүүлийн үеийн",
     "Import" : "Импорт",
     "Export" : "Экспорт",
     "Recently added" : "Сүүлд нэмэгдсэн",
     "Last modified" : "Сүүлд өөрчилсөн",
     "Clear data" : "Өгөгдлийг цэвэрлэх",
-    "URL" : "URL",
+    "Title" : "Цол/Албан тушаал",
+    "Link" : "Холбоос",
     "Tags" : "Tag-үүд",
+    "Attachments" : "Хавсралт",
     "Notes" : "Шинэ ",
-    "Sharing" : "Түгээх",
     "Owner" : "Эзэмшигч",
+    "Sharing" : "Түгээх",
     "Share link" : "Холбоос хуваалцах",
     "Allow editing" : "Засварлахыг зөвшөөрөх",
     "Select" : "Сонгох",
     "Privacy" : "Хувийн нууц",
-    "Title" : "Цол/Албан тушаал",
-    "Link" : "Холбоос",
-    "Folder" : "Хавтас"
+    "Folder" : "Хавтас",
+    "Save" : "Хадгалах"
 },
 "nplurals=2; plural=(n != 1);");
