@@ -6,24 +6,28 @@ OC.L10N.register(
     "Rename" : "Renomear",
     "Move" : "Mover",
     "Delete" : "Apagar",
-    "Save" : "Guardar",
+    "New" : "Novo",
     "New folder" : "Nova pasta",
     "Grid view" : "Vista em grelha",
     "List view" : "Vista em lista",
-    "Create" : "Criar",
-    "Cancel" : "Cancelar",
-    "Public" : "Público",
+    "Select all" : "Seleccionar todos",
     "Root folder" : "Pasta raiz",
+    "Cancel" : "Cancelar",
+    "All bookmarks" : "Todos os marcadores",
+    "Recent" : "Recentes",
+    "Add a bookmark" : "Adicionar um marcador",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Recently added" : "Adicionados recentemente",
     "Last modified" : "Última modificação",
     "Clear data" : "Limpar dados",
-    "URL" : "URL",
+    "Title" : "Título",
+    "Link" : "Link",
     "Tags" : "Marcações",
+    "Attachments" : "Anexos",
     "Notes" : "Notas",
-    "Sharing" : "Partilha",
     "Owner" : "Proprietário",
+    "Sharing" : "Partilha",
     "Select a user or group" : "Selecionar utilizador ou grupo",
     "Share link" : "Share link",
     "Copy link" : "Copiar hiperligação",
@@ -31,9 +35,7 @@ OC.L10N.register(
     "Link copied" : "Link copiado",
     "Select" : "Seleccionar",
     "Privacy" : "Privacidade",
-    "Add a bookmark" : "Adicionar um marcador",
-    "Title" : "Título",
-    "Link" : "Link",
-    "Folder" : "Pasta"
+    "Folder" : "Pasta",
+    "Save" : "Guardar"
 },
 "nplurals=2; plural=(n != 1);");
