@@ -5,26 +5,26 @@ OC.L10N.register(
     "Rename" : "เปลี่ยนชื่อ",
     "Move" : "Move",
     "Delete" : "ลบ",
-    "Save" : "บันทึก",
+    "New" : "ใหม่",
     "New folder" : "โฟลเดอร์ใหม่",
     "Grid view" : "มุมมองแบบตาราง Grid",
     "List view" : "มุมมองแบบแสดงรายการ",
-    "Create" : "สร้าง",
+    "Select all" : "เลือกทั้งหมด",
     "Cancel" : "ยกเลิก",
     "Import" : "นำเข้า",
     "Export" : "ส่งออก",
     "Alphabetically" : "เรียงตามตัวอักษร",
-    "URL" : "URL",
+    "Title" : "ชื่อเรื่อง",
+    "Link" : "ลิงค์",
     "Tags" : "ป้ายกำกับ",
     "Notes" : "บันทึกย่อ",
-    "Sharing" : "แชร์ข้อมูล",
     "Owner" : "Owner",
+    "Sharing" : "แชร์ข้อมูล",
     "Share link" : "แชร์ลิงค์",
     "Copy link" : "คัดลอกลิงค์",
     "Allow editing" : "อนุญาตให้แก้ไข",
     "Select" : "Select",
-    "Title" : "ชื่อเรื่อง",
-    "Link" : "ลิงค์",
-    "Folder" : "แฟ้มเอกสาร"
+    "Folder" : "แฟ้มเอกสาร",
+    "Save" : "บันทึก"
 },
 "nplurals=1; plural=0;");
