@@ -32,22 +32,56 @@ class SettingsController extends ApiController {
 
 	/** @var string */
 	private $userId;
+	/**
+	 * @var \OCP\IL10N
+	 */
+	private $l;
 
 	/**
 	 * @param string $appName
 	 * @param IRequest $request
 	 * @param string $userId
 	 * @param IConfig $config
+	 * @param \OCP\IL10N $l
 	 */
 	public function __construct(
-		$appName,
-		$request,
-		$userId,
-		IConfig $config
+		$appName, $request, $userId, IConfig $config, \OCP\IL10N $l
 	) {
 		parent::__construct($appName, $request);
 		$this->config = $config;
 		$this->userId = $userId;
+		$this->l = $l;
+	}
+
+	private function getSetting(string $key, string $name, $default) {
+		try {
+			$userValue = $this->config->getUserValue(
+				$this->userId,
+				$this->appName,
+				$key,
+				$default
+			);
+		} catch (\Exception $e) {
+			\OCP\Util::writeLog('bookmarks', $e->getMessage(), \OCP\Util::ERROR);
+			return new JSONResponse([], Http::STATUS_INTERNAL_SERVER_ERROR);
+		}
+
+		return new JSONResponse([$name => $userValue], Http::STATUS_OK);
+	}
+
+	private function setSetting($key, $value) {
+		try {
+			$this->config->setUserValue(
+				$this->userId,
+				$this->appName,
+				$key,
+				$value
+			);
+		} catch (\Exception $e) {
+			return new JSONResponse(['status' => 'error'], Http::STATUS_INTERNAL_SERVER_ERROR);
+		}
+
+		return new JSONResponse(['status' => 'success'], Http::STATUS_OK);
 	}
 
 	/**
@@ -58,18 +92,7 @@ class SettingsController extends ApiController {
 	 * @NoAdminRequired
 	 */
 	public function getSorting() {
-		try {
-			$sorting = $this->config->getUserValue(
-				$this->userId,
-				$this->appName,
-				'sorting',
-				'lastmodified' //default value
-			);
-		} catch (\Exception $e) {
-			return new JSONResponse([], Http::STATUS_INTERNAL_SERVER_ERROR);
-		}
-
-		return new JSONResponse(['sorting' => $sorting], Http::STATUS_OK);
+		return $this->getSetting('sorting', 'sorting', 'lastmodified');
 	}
 
 	/**
@@ -81,22 +104,14 @@ class SettingsController extends ApiController {
 	 * @NoAdminRequired
 	 */
 	public function setSorting($sorting = "") {
-		$legalArguments = ['title', 'added', 'clickcount', 'lastmodified'];
+		$legalArguments = ['title', 'added', 'clickcount', 'lastmodified', 'index'];
 		if (!in_array($sorting, $legalArguments)) {
 			return new JSONResponse(['status' => 'error'], Http::STATUS_BAD_REQUEST);
 		}
-		try {
-			$this->config->setUserValue(
-				$this->userId,
-				$this->appName,
+		return $this->setSetting(
 				'sorting',
 				$sorting
 			);
-		} catch (\Exception $e) {
-			return new JSONResponse(['status' => 'error'], Http::STATUS_INTERNAL_SERVER_ERROR);
-		}
-
-		return new JSONResponse(['status' => 'success'], Http::STATUS_OK);
 	}
 
 	/**
@@ -107,18 +122,7 @@ class SettingsController extends ApiController {
 	 * @NoAdminRequired
 	 */
 	public function getViewMode() {
-		try {
-			$viewMode = $this->config->getUserValue(
-				$this->userId,
-				$this->appName,
-				'viewMode',
-				'grid' //default value
-			);
-		} catch (\Exception $e) {
-			return new JSONResponse([], Http::STATUS_INTERNAL_SERVER_ERROR);
-		}
-
-		return new JSONResponse(['viewMode' => $viewMode], Http::STATUS_OK);
+		return $this->getSetting('viewMode', 'viewMode', 'grid');
 	}
 
 	/**
@@ -134,18 +138,10 @@ class SettingsController extends ApiController {
 		if (!in_array($viewMode, $legalArguments)) {
 			return new JSONResponse(['status' => 'error'], Http::STATUS_BAD_REQUEST);
 		}
-		try {
-			$this->config->setUserValue(
-				$this->userId,
-				$this->appName,
+		return $this->setSetting(
 				'viewMode',
 				$viewMode
 			);
-		} catch (\Exception $e) {
-			return new JSONResponse(['status' => 'error'], Http::STATUS_INTERNAL_SERVER_ERROR);
-		}
-
-		return new JSONResponse(['status' => 'success'], Http::STATUS_OK);
 	}
 
 	/**
@@ -159,4 +155,30 @@ class SettingsController extends ApiController {
 		$limit = (int)$this->config->getAppValue('bookmarks', 'performance.maxBookmarksperAccount', 0);
 		return new JSONResponse(['limit' => $limit], Http::STATUS_OK);
 	}
+
+	/**
+	 * get user-defined archive path
+	 *
+	 * @return JSONResponse
+	 *
+	 * @NoAdminRequired
+	 */
+	public function getArchivePath() {
+		return $this->getSetting(
+			'archive.filePath',
+			'archivePath',
+			$this->l->t('Bookmarks')
+		);
+	}
+
+	/**
+	 * set user-defined archive path
+	 *
+	 * @return JSONResponse
+	 *
+	 * @NoAdminRequired
+	 */
+	public function setArchivePath($archivePath) {
+		return $this->setSetting('archive.filePath', $archivePath);
+	}
 }
